<center><h1>PROJET</h1></center>


#### Objectif: Automatisation de déploiement  
L'objectif est d'automatiser des déploiements à l'aide de playbook Ansible et de son écosystème    

Ce projet devra comprendre un :  
    - Déploiement serveur (nginx, mysql, php, composer, nodejs)  
    - Déploiement applicatif (ProjectSend)  
        - https://github.com/projectsend/projectsend

#### Groupe ou individuel:  
Ce projet peut se faire en binôme ou individuellement

#### Consignes:
- Le projet doit être mis sur un repository dans le [gitlab](https://forge.univ-lyon1.fr) de l'université.  
     - Le professeur doit être ajouté en tant que `owner` aux membres du repository  (@yohann.valentin)
    
- Un readme doit être présent dans le projet avec les rubriques suivantes :  
    - Liste des étudiants.
        - Comportant: nom - prénom - numéro étudiant
    - Les clés ssh de connexion :
        - aux serveurs openstack (VM)
        - aux repositories gitlab
    - La liste des `roles` (si utilisés).
    - La liste des commandes à utiliser.  
    Ceux-ci pourront aussi être présents dans un makefile
    - Une présentation de l'architecture mise en place


#### Architecture/Environnement
L'architecture doit permettre le déploiement sur des environnements de :
- preprod  
- prod  

#### Serveur
**!! ATTENTION !!! PAS DE ROLE PROVENANT DE LA COMMUNAUTÉ GALAXY POUR LA PARTIE APPLICATIF**
Il doit être possible de déployer les parties suivantes (séparément ou "all-in-one") :
  - apt:
    - zip
    - unzip
  - serveur web  (nginx)
    - Configuration: Activer le Gzip (https://www.digitalocean.com/community/tools/nginx)    
    - Vhost pour Symfony: [https://symfony.com/doc/current/setup/web_server_configuration.html#nginx]
  - base de données (mysql)
    - config: create database / create user and password
  - applicatif (php / composer / git / npm )
    - php
        - version 7.4
        - Extensions:  php7.4-mysql php7.4-mbstring php7.4-gd php7.4-xml php-7.4-gmp php-7.4-zip
        - config: 
          - max_execution_time: 60
          - memory_limit: 256M
    - composer:
      - version 1.*
      - la commande suivante suffit normalement: `apt install composer`
    - nodejs / npm

#### Applicatif
** Possibilité d'utiliser le role suivant : https://github.com/ansistrano/deploy**
La stratégie de déploiement doit permettre du `atomic deployments`

> **Atomic deployments** are a style of code deployment that symlink the most recent version of the code 
> so it’s available to the web server to serve.

> **Atomic deployment** – Make updates available only when they are complete and totally in place.

- Ressource pour en savoir plus sur l'atomic deployment
    - https://deploybot.com/blog/deploy-complex-apps-with-atomic-sftp-deployments (lire les 3 premières parties)
    - https://www.ewaldvanderveken.dev/zero-downtime-deployment-of-your-symfony-project-using-capistrano-and-gitlab-ci/ (lire la première partie)

```
-- /var/www/html/projectsend
|-- current -> /var/www/html/projectsend/releases/20200512131539
|-- releases
|   |-- 20200512131539
|   |-- 20200509150741
|   |-- 20200509145325
|-- shared
```

- Le déploiement de l'applicatif doit prendre en compte la version (release) de l'applicatif (https://github.com/projectsend/projectsend/releases)

- Le chemin de base pour l'installation de l'applicatif sera différent en fonction du serveur  
    - preprod: /var/www/html/preprod/project_send/...  
    - prod: /var/www/html/prod/project_send/...  

- L'applicatif doit comporter une connexion à la base de données  
**Chaque environnement doit avoir sa propre base de données avec un user et un mot de passe différent.**

Exemple:

    - preprod:  
        - user: project_send_preprod  
        - pwd: project_send_preprod  
    - prod:  
        - user: project_send_prod  
        - pwd: project_send_prod  


- Install les dépendances PHP:
    - composer install

- Variable d'environnement du projet project_send pour la configuration de la base de données dans le ficher `sys.config.php` (fichier d'origine: `includes/sys.config.sample.php`)
    
- Install et Compiler le JS et SCSS:
    - npm install
    - run gulp: `./node_modules/gulp/bin/gulp.js`

- Le dossier `upload` dans projectSend doit être partagé (shared) entre les différentes versions de déploiement
    
#### Conseils
- Un code organiser/structurer, tu feras
- Sur une/des nouvelle(s) machine(s) (hôte/VM), le professeur lancera -  sans erreur, les playbooks seront

#### Bonus
- Des tests applicatifs pourront être lancés via un playbook (phpunit)
- Si des `roles` ont été créés ceux-ci pourront être testés avec [Molecule](https://molecule.readthedocs.io/en/latest/)

#### Tips
###### Playbook
Afin de bypass le proxy sur l'execution d'un playbook, vous pouvez ajouter au debut de vos playbooks les élements suivants (pour un exemple complet: [playbook-example.yaml](playbook-example.yaml)):
```
  vars:
    proxy: "http://proxy.univ-lyon1.fr:3128/"
  environment:
    http_proxy: "{{proxy}}"
    https_proxy: "{{proxy}}"
    APT_KEY_DONT_WARN_ON_DANGEROUS_USAGE: DontWarn
```
